# PyLUSAT

[![PyPI version](https://img.shields.io/pypi/v/pylusat)](https://pypi.org/project/pylusat/)
![PyPI - Python version](https://img.shields.io/pypi/pyversions/pylusat)

Python Land-Use Suitability Analysis Toolkit

## Introduction
PyLUSAT intends to provide users with tools that can be used to conduct land-use 
suitability analysis.

## Install
PyLUSAT depends on the following packages.
- geopandas
- rasterio
- rasterstats
- scipy
